[cairo-commit] cairomm/cairomm context.cc, 1.14, 1.15 context.h, 1.18, 1.19

Jonathon Jongsma commit at pdx.freedesktop.org
Fri Aug 18 10:03:36 PDT 2006


Committed by: jjongsma

Update of /cvs/cairo/cairomm/cairomm
In directory kemper:/tmp/cvs-serv27225/cairomm

Modified Files:
	context.cc context.h 
Log Message:
2006-08-18  Jonathon Jongsma  <jonathon.jongsma at gmail.com>

	* cairomm/context.cc:
	* cairomm/context.h: API CHANGE: some API was changed to maintain a closer
	similarity to the underlying cairo API (while also attempting to avoid
	confusion with the C++ 'new' keyword) in preparation for freezing the
	cairomm API.  Two functions are affected:
		- Context::clear_path() -> Context::begin_new_path()
		- Context::new_sub_path() -> Context::begin_new_sub_path()
	* configure.in: bump the libtool version to indicate API change


Index: context.cc
===================================================================
RCS file: /cvs/cairo/cairomm/cairomm/context.cc,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -d -r1.14 -r1.15
--- context.cc	16 Aug 2006 02:27:45 -0000	1.14
+++ context.cc	18 Aug 2006 17:03:33 -0000	1.15
@@ -223,13 +223,13 @@
   check_object_status_and_throw_exception(*this);
 }
 
-void Context::clear_path()
+void Context::begin_new_path()
 {
   cairo_new_path(m_cobject);
   check_object_status_and_throw_exception(*this);
 }
 
-void Context::new_sub_path()
+void Context::begin_new_sub_path()
 {
   cairo_new_sub_path(m_cobject);
   check_object_status_and_throw_exception(*this);

Index: context.h
===================================================================
RCS file: /cvs/cairo/cairomm/cairomm/context.h,v
retrieving revision 1.18
retrieving revision 1.19
diff -u -d -r1.18 -r1.19
--- context.h	16 Aug 2006 01:38:35 -0000	1.18
+++ context.h	18 Aug 2006 17:03:33 -0000	1.19
@@ -351,7 +351,7 @@
 
   /** Clears the current path. After this call there will be no current point.
    */
-  void clear_path();
+  void begin_new_path();
 
   /** Begin a new subpath. Note that the existing path is not affected. After
    * this call there will be no current point.
@@ -359,12 +359,12 @@
    * In many cases, this call is not needed since new subpaths are frequently
    * started with move_to().
    *
    * A call to new_sub_path() is particularly useful when beginning a new
    * subpath with one of the arc() calls. This makes things easier as it is no
    * longer necessary to manually compute the arc's initial coordinates for a
    * call to move_to().
    */
-  void new_sub_path();
+  void begin_new_sub_path();
 
   /** If the current subpath is not empty, begin a new subpath. After this call
    * the current point will be (x, y).
@@ -359,12 +359,12 @@
    * started with move_to().
    *
-   * A call to new_sub_path() is particularly useful when beginning a new
+   * A call to begin_new_sub_path() is particularly useful when beginning a new
    * subpath with one of the arc() calls. This makes things easier as it is no
    * longer necessary to manually compute the arc's initial coordinates for a



More information about the cairo-commit mailing list